@@ -48,7 +48,7 @@ dtt_day.POSIXct <- function(x, ...) {
 `dtt_day<-.Date` <- function(x, value) {
   chk_whole_numeric(value)
   chk_range(value, c(0L, 31L))
-  chk_subset(length(value), c(1L, length(value)))
+  chk_subset(length(value), c(1L, length(x)))
 
   if (!length(x)) {
     return(x)
@@ -65,7 +65,7 @@ dtt_day.POSIXct <- function(x, ...) {
 `dtt_day<-.POSIXct` <- function(x, value) {
   chk_whole_numeric(value)
   chk_range(value, c(0L, 31L))
-  chk_subset(length(value), c(1L, length(value)))
+  chk_subset(length(value), c(1L, length(x)))
 
   if (!length(x)) {
     return(x)
