@@ -3,6 +3,7 @@
 #' Coerces vectors to floored (and wrapped) hms vectors.
 #'
 #' @param x A vector.
+#' @param value A time vector.
 #' @param ... Unused.
 #'
 #' @return A floored hms vector.
@@ -18,6 +19,12 @@ dtt_time <- function(x, ...) {
   UseMethod("dtt_time")
 }
 
+#' @rdname dtt_time
+#' @export
+`dtt_time<-` <- function(x, value) {
+  UseMethod("dtt_time<-")
+}
+
 #' @describeIn dtt_time Coerce integer vector to a floored hms vector
 #' @export
 dtt_time.integer <- function(x, ...) {
@@ -68,3 +75,29 @@ dtt_time.POSIXlt <- function(x, ...) {
   x <- data.frame(seconds = x$sec, minutes = x$min, hours = x$hour)
   do.call("hms", x)
 }
+
+#' @describeIn dtt_date Set time values for a Date vector
+#' @export
+`dtt_time<-.Date` <- function(x, value) {
+  x <- dtt_date_time(x)
+  dtt_time(x) <- value
+  x
+}
+
+#' @describeIn dtt_date Set date values for a POSIXct vector
+#' @export
+`dtt_time<-.POSIXct` <- function(x, value) {
+  chk_s3_class(value, "hms")
+  chk_subset(length(value), c(1L, length(x)))
+
+  if (!length(x)) {
+    return(x)
+  }
+  value <- dtt_time(value)
+  tz <- dtt_tz(x)
+  x <- as.POSIXlt(x, tz = tz)
+  x$hour <- dtt_hour(value)
+  x$min <- dtt_minute(value)
+  x$sec <- dtt_second(value)
+  as.POSIXct(format(x), tz = tz)
+}
